from .general_models import NewsClassfiction_CNN, NewsClassification_RNN, NewsClassification_WordAVGModel
from .transformer_models import NewsTransformerDataProcessor,NewsClsTask
